/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 */
 
#include <libgnomedbmm.h>
#include <libgdamm.h>
#include <gtkmm.h>

#include <iostream>

#include "examplewindow.h"

int main(int argc, char* argv[])
{
  Gtk::Main kit(argc, argv);
  Gnome::Db::init("Mandatory example", "1.0", argc, argv);

  Glib::RefPtr<Gnome::Gda::Dict> dict = Gnome::Gda::Dict::create();
  try
  {
    // We use a Gda::Dict here to read the information how to map DMBS types to Gda types from an xml file.
    // A Gda::Dict is a powerful repository to store informations about the underlying database and read/write them
    // to xml in an efficient way. Besides types it can also store other informations such as functions and aggregates.
    std::string filename = Glib::build_filename(LIBGNOMEDB_DATADIR, "demo_dict.xml");
    dict->load_xml_file(filename);

    Glib::ustring connection_string = "DB_DIR=" LIBGNOMEDB_DATADIR ";DB_NAME=demo_db";

    // Create a connection to the embedded sqlite database
    Glib::RefPtr<Gnome::Gda::Client> client = Gnome::Gda::Client::create();
    Glib::RefPtr<Gnome::Gda::Connection> cnc = client->open_connection_from_string("SQLite" /* provider */, 
      connection_string, "" /* username */, "" /* password */);
    
    // Associate the connection with the edit
    dict->set_connection(cnc);
  }
  catch(const Glib::Error& err)
  {
    std::cerr << err.what() << std::endl;
    exit(1);
  }

  ExampleWindow window(dict);

  kit.run(window);
  return 0;
}
