/*
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Library General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor Boston, MA 02110-1301,  USA
 */

#include <libgnomedbmm.h>
#include <libgdamm.h>

#include <iostream>

int main(int argc, char* argv[])
{
  Gnome::Db::init("Queries example", "1.0", argc, argv);

  Glib::RefPtr<Gnome::Gda::Dict> dict = Gnome::Gda::Dict::create();
  try
  {
    Glib::RefPtr<Gnome::Gda::Client> client = Gnome::Gda::Client::create();
    Glib::ustring connection_string = "DB_DIR=" LIBGNOMEDB_DATADIR ";DB_NAME=demo_db";

    Glib::RefPtr<Gnome::Gda::Connection> cnc = client->open_connection_from_string("SQLite", connection_string, "" /* username */, "" /* password */);
    dict->set_connection(cnc);

    dict->update_dbms_meta_data();
  }
  catch(const Glib::Error& err)
  {
    std::cerr << "Exception caught: " << err.what() << std::endl;
    return 1;
  }

  // Specifies that this is a DELETE query.
  Glib::RefPtr<Gnome::Gda::Query> query = Gnome::Gda::Query::create(dict, Gnome::Gda::QUERY_TYPE_DELETE);

  // Delete queries may only have one target.
  Glib::RefPtr<Gnome::Gda::QueryTarget> products = Gnome::Gda::QueryTarget::create(query, "products");
  query->add_target(products);

  // Create a condition that tests two fields for equality, to not delete
  // the whole table.
  Glib::RefPtr<Gnome::Gda::QueryCondition> condition = Gnome::Gda::QueryCondition::create(query, Gnome::Gda::QUERY_CONDITION_LEAF_EQUAL);
  // Left operand is the ref field in the table
  condition->leaf_set_operator(Gnome::Gda::QUERY_CONDITION_OP_LEFT, Gnome::Gda::QueryFieldField::create(query, "ref", products));
  // Right operand is the constant '42'. This way, all rows whose ref field
  // contains 42 will be deleted.
  condition->leaf_set_operator(Gnome::Gda::QUERY_CONDITION_OP_RIGHT, Gnome::Gda::QueryFieldValue::create(query, Gnome::Gda::Value(42)));

  // Associate the condition to the query
  query->set_condition(condition);

  // Prints "DELETE FROM products WHERE ref=42"
  std::cout << query->get_sql_text() << std::endl;

  return 0;
}
